@@ -5,6 +5,7 @@ from .widgets import (
     Container,
     DateEdit,
     DateTimeEdit,
+    Dialog,
     EmptyWidget,
     FloatSlider,
     FloatSpinBox,
@@ -34,6 +35,7 @@ __all__ = [
     "Container",
     "DateEdit",
     "DateTimeEdit",
+    "Dialog",
     "EmptyWidget",
     "FloatSlider",
     "FloatSpinBox",
