@@ -59,6 +59,8 @@ _SIMPLE_TYPES = {
     datetime.datetime: widgets.DateTimeEdit,
     range: widgets.RangeEdit,
     slice: widgets.SliceEdit,
+    list: widgets.ListEdit,
+    tuple: widgets.TupleEdit,
 }
 
 
@@ -82,8 +84,13 @@ def match_type(tw: TypeWrapper) -> WidgetTuple | None:
         return widgets.FunctionGui, {"function": tw.default}  # type: ignore
 
     # sequence of paths
-    if tw.shape in tw.SHAPE.SEQUENCE_LIKE and _is_subclass(tw.type_, pathlib.Path):
-        return widgets.FileEdit, {"mode": "rm"}
+    if tw.shape in tw.SHAPE.SEQUENCE_LIKE:
+        if _is_subclass(tw.type_, pathlib.Path):
+            return widgets.FileEdit, {"mode": "rm"}
+        elif tw.shape == tw.SHAPE.LIST:
+            return widgets.ListEdit, {}
+        elif tw.shape == tw.SHAPE.TUPLE:
+            return widgets.TupleEdit, {}
     return None
 
 
@@ -336,11 +343,12 @@ def register_type(
                 )
         elif widget_type is not None:
 
-            if not isinstance(
-                widget_type, (str, widgets._bases.Widget, WidgetProtocol)
+            if not isinstance(widget_type, (str, WidgetProtocol)) and not (
+                inspect.isclass(widget_type) and issubclass(widget_type, widgets.Widget)
             ):
                 raise TypeError(
-                    '"widget_type" must be either a string, Widget, or WidgetProtocol'
+                    '"widget_type" must be either a string, WidgetProtocol, or '
+                    "Widget subclass"
                 )
             _TYPE_DEFS[_type_] = (widget_type, _options)
         elif "bind" in _options:
