@@ -79,9 +79,13 @@ class FunctionGui(Container, Generic[_R]):
         If True, create an additional button that calls the original function when
         clicked.  If a ``str``, set the button text. by default False when
         auto_call is True, and True otherwise.
+        The button can be accessed from the ``.call_button`` property.
     layout : str, optional
         The type of layout to use. Must be one of {'horizontal', 'vertical'}.
         by default "horizontal".
+    scrollable : bool, optional
+        Whether to enable scroll bars or not. If enabled, scroll bars will
+        only appear along the layout direction, not in both directions.
     labels : bool, optional
         Whether labels are shown in the widget. by default True
     tooltips : bool, optional
@@ -122,6 +126,7 @@ class FunctionGui(Container, Generic[_R]):
         function: Callable[..., _R],
         call_button: bool | str | None = None,
         layout: str = "vertical",
+        scrollable: bool = False,
         labels: bool = True,
         tooltips: bool = True,
         app: AppRef = None,
@@ -170,6 +175,7 @@ class FunctionGui(Container, Generic[_R]):
 
         super().__init__(
             layout=layout,
+            scrollable=scrollable,
             labels=labels,
             visible=visible,
             widgets=list(sig.widgets(app).values()),
@@ -228,6 +234,11 @@ class FunctionGui(Container, Generic[_R]):
         if self._auto_call:
             self()
 
+    @property
+    def call_button(self) -> PushButton | None:
+        """Return the call button."""
+        return self._call_button
+
     @property
     def call_count(self) -> int:
         """Return the number of times the function has been called."""
@@ -324,12 +335,6 @@ class FunctionGui(Container, Generic[_R]):
         """Return string representation of instance."""
         return f"<{type(self).__name__} {self._callable_name}{self.__signature__}>"
 
-    def asdict(self) -> dict[str, Any]:
-        """Return state of widget as dict."""
-        return {
-            w.name: getattr(w, "value", None) for w in self if w.name and not w.gui_only
-        }
-
     def update(
         self,
         mapping: Mapping | Iterable[tuple[str, Any]] | None = None,
